Skip to main contentCrate wlib
Source - keyboard
- keys
- Useful keyboard related types
Contains all physical keycodes from “/usr/include/linux/input-event-codes.h”
- Context
- The information passed to your
update() each frame - MouseState
- State of the mouse
- PointerEvent
- A single pointer event.
- WLibSettings
- The available settings to configure window stuff
- WindowSize
- The pixel size of a window
- Event
- The possible event types you can get from
Context::event_queue - MouseButton
- Supported MouseButtons.
If you need extra mouse buttons, look at the event queue and use numbers from
/usr/include/linux/input-event-codes.h - PointerEventKind
- WLibRequest
- Some information you want to tell WLib.
- WindowAble
- The trait you must implement to create a window
- run
- Runs a struct implementing
WindowAble by setting up a wayland event loop.