Crate wlib

Crate wlib 

Modules

keyboard

Structs

Context
The information passed to your update() each frame
MouseState
State of the mouse
PointerEvent
A single pointer event.
WLibSettings
The available settings to configure window stuff
WindowSize

Enums

Event
The possible event types you can get from Context::event_queue
MouseButton
Supported MouseButtons. If you need extra mouse buttons, look at the event queue and use numbers from /usr/include/linux/input-event-codes.h
PointerEventKind
WLibRequest
Some information you want to tell WLib.

Traits

WindowAble
The trait you must implement to create a window

Functions

run