Modules
Structs
- Context
- The information passed to your
update()each frame - Mouse
State - State of the mouse
- Pointer
Event - A single pointer event.
- WLib
Settings - The available settings to configure window stuff
- Window
Size
Enums
- Event
- The possible event types you can get from
Context::event_queue - Mouse
Button - Supported MouseButtons.
If you need extra mouse buttons, look at the event queue and use numbers from
/usr/include/linux/input-event-codes.h - Pointer
Event Kind - WLib
Request - Some information you want to tell WLib.
Traits
- Window
Able - The trait you must implement to create a window